@@ -19,7 +19,7 @@
 	*/
 
 	// ============================= //
-	// lang_admin.php - Français 1.2 //
+	// lang_admin.php - Français 1.3 //
 	// ============================= //
 
 	// Français formel (Vous) //
@@ -75,11 +75,11 @@
 	$lang['no_activated_entries'] = "Aucune entrée activée";
 	$lang['no_spam_entries'] = "No spam entries available.";
 	$lang['entries_on_pages'] = "Entrées sur {PAGES} pages";
-	$lang['page_first'] = "First page";
+	$lang['page_first'] = "Aller à la première page";
 	$lang['page_first_symbol'] = "&laquo;";
 	$lang['page_forwards'] = "Aller à la page suivante";
 	$lang['page_forwards_symbol'] = "&rsaquo;";
-	$lang['page_last'] = "Last page";
+	$lang['page_last'] = "Aller à la dernière page";
 	$lang['page_last_symbol'] = "&raquo;";
 	$lang['page_backwards'] = "Aller à la page précédente";
 	$lang['page_backwards_symbol'] = "&lsaquo;";
@@ -88,20 +88,20 @@
 	$lang['activate_entry'] = "Activer cette entrée";
 	$lang['deactivate_entry'] = "Désactiver cette entrée";
 	$lang['delete_entry'] = "Supprimer cette entrée";
-	$lang['mark_as_spam'] = "Mark as spam";
-	$lang['nospam_entry'] = "Mark entry as 'no spam' and activate it";
-	$lang['nospam_deactivate_entry'] = "Mark entry as 'no spam' but let it deactivated";
+	$lang['mark_as_spam'] = "Marquer comme Spam";
+	$lang['nospam_entry'] = "Marquer l’entrée comme 'pas un Spam' et activer cette entrée";
+	$lang['nospam_deactivate_entry'] = "Marquer l’entrée comme 'pas un Spam', mais la laisser désactivée";
 	$lang['active'] = "Cette entrée est activée dans le livre d’hôtes.";
 	$lang['inactive'] = "Cette entrée n’est pas activée dans le livre d’hôtes.";
 	$lang['edit_entry'] = "Éditer cette entrée";
-	$lang['do_nothing'] = "Do nothing ...";
-	$lang['delete_whole_spam'] = "Delete all spam entries";
-	$lang['mark_all_no_spam_deactivate'] = "Mark all entries as 'no spam' and activate it";
-	$lang['mark_all_no_spam_activate'] = "Mark all entries as 'no spam' but let them deactivated";
-	$lang['mark_all_as_spam'] = "Mark all entries as spam";
-	$lang['activate_all_entries'] = "Activate all entries";
-	$lang['deactivate_all_entries'] = "Deactivate all entries";
-	$lang['delete_all_entries'] = "Delete all entries";
+	$lang['do_nothing'] = "Ne rien faire...";
+	$lang['delete_whole_spam'] = "Effacer toutes les entrées Spam";
+	$lang['mark_all_no_spam_deactivate'] = "Marquer toutes les entrées comme 'pas un Spam' et les activer";
+	$lang['mark_all_no_spam_activate'] = "Marquer toutes les entrées comme 'pas un Spam', mais les laisser désactivées";
+	$lang['mark_all_as_spam'] = "Marquer toutes les entrées comme Spam";
+	$lang['activate_all_entries'] = "Activer toutes les entrées";
+	$lang['deactivate_all_entries'] = "Désactiver toutes les entrées";
+	$lang['delete_all_entries'] = "Effacer toutes les entrées";
 
 	$lang['sendmail_user_notification_title'] = "Votre entrée sur {DOMAIN} a été activée.";
 	$lang['sendmail_user_comment_title'] = "Sur votre entrée sur {DOMAIN} un commentaire a été déposé.";
@@ -123,9 +123,9 @@
 	$lang['deactivate'] = "Désactiver entrée";
 	$lang['delete'] = "Supprimer entrée";
 	$lang['edit'] = "Éditer entrée";
-	$lang['spam'] = "Spam entries";
+	$lang['spam'] = "Entrées classées comme Spam";
 	$lang['users'] = "Administration d’utilisateurs";
-	$lang['stats'] = "Statistics";
+	$lang['stats'] = "Statistiques";
 	$lang['license'] = "Licence";
 	$lang['forum'] = "Forum";
 	$lang['bugreport'] = "Signaler une erreur";
@@ -164,10 +164,13 @@
 	$lang['edit_bbcode'] = "BBcodes:";
 	$lang['edit_smileys'] = "Smileys:";
 	$lang['edit_captcha'] = "Code de sécurité:";
-	$lang['edit_captcha_method'] = "Sort of captcha:";
+	$lang['edit_captcha_method'] = "Type de Captcha:";
 	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
-	$lang['edit_akismet_api'] = "Akismet API Key:";
-	$lang['edit_akismet_mark_as_spam'] = "Spam marking:";
+	$lang['edit_akismet_api'] = "Akismet API Key (obligatoire):";
+	$lang['edit_akismet_mark_as_spam'] = "Indication Spam:";
+	$lang['edit_time_lock'] = "Blocage d'envoi:";
+	$lang['edit_time_lock_value'] = "Temps minimal pour le blocage d'envoi:";
+	$lang['edit_time_lock_maxtime'] = "Temps maximal pour le blocage d'envoi:";
 	$lang['edit_user_notification'] = "Notification à l’utilisateur:";
 	$lang['edit_user_show_email'] = "E-Mail d’utilisateur dans le livre d’hôtes:";
 	$lang['edit_session_timeout'] = "Temps max. d’une session:";
@@ -205,12 +208,15 @@
 	$lang['edit_expl_bbcode'] = "Permet une mise en forme du texte par l'utilisateur.";
 	$lang['edit_expl_smileys'] = "Permet à l'utilisateur d'insérer des smileys.";
 	$lang['edit_expl_captcha'] = "Si cette option est activée, on doit entrer un code de sécurité pour déposer une nouvelle entrée et envoyer un e-Mail à un utilisateur.";
-	$lang['edit_expl_captcha_method'] = "You can choose between a securitycode, or a mathematic formula the user has to solve.";
-	$lang['edit_expl_akismet_plugin'] = "Akismet is an external anti-spam-service, that checks new entries on spam. The akismet-plugin can be downloaded at <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.";
-	$lang['edit_expl_akismet_api'] = "In order to use Akismet you need an <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a>. Sign in for free and enter it here after registration.";
-	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet is installed!</span>";
-	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet is NOT installed!</span>";
-	$lang['edit_expl_akismet_mark_as_spam'] = "If this option is enabled, positive Akismet entries are marked as spam and appear in the administration panel so you can check them for yourself and decide what to do with.";
+	$lang['edit_expl_captcha_method'] = "Vous pouvez choisir entre un code de sécurité classique ou un code de sécurité mathématique, pour lequel l’utilisateur doit résoudre un calcul mathématique.";
+	$lang['edit_expl_akismet_plugin'] = "Akismet est un service Anti-Spam externe, qui examine les nouvelles entrées. Si une entrée est classée comme Spam, elle est automatiquement marquée et désactivée."; /* Ich weiss jetzt nicht genau, wie sich Akismet im MGB verhält, bzw. welche Optionen man einstellen kann. Habe die neue Version des MGB noch nicht getestet. Wenn man wählen kann zwischen automatischer Blockierung der Spam Einträge, oder dass sie lediglich markiert und deaktiviert werden, dann bitte diesen String so stehen lassen. Wird der Spam immer automatisch blockiert, dann bitte den Teil nach "refusée" streichen. Wird dagegen der Spam immer markiert und deaktiviert, dann bitte den Teil "refusée ou" löschen.  	*/
+	$lang['edit_expl_akismet_api'] = "Pour utiliser le service Akismet, l’Akismet-Plugin et une <a href='http://akismet.com/signup/#free' title='Akismet API Key'>clé API</a> sont nécessaires. Après avoir été enregistré, vous pouvez entrer la clé ici.";
+	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version'>Akismet est installé!</span>";
+	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version'>Akismet N’EST PAS installé!</span>";
+	$lang['edit_expl_akismet_mark_as_spam'] = "Si cette option est activée, toutes les nouvelles entrées classées ‘positives’ par Akismet, seront marquées comme Spam et apparaîtront dans le panneau d’administration, où vous pourrez les contrôler vous même. Ensuite, vous pourrez décider quoi en faire.";
+	$lang['edit_expl_time_lock'] = "Lorsque cette option est activée, un chronomètre fonctionne en arrière plan pour chaque nouvelle entrée dans le livre d'or. Si l'utilisateur envoie le formulaire avant que le chronomètre soit arrêté, il lui sera signalé qu'il est trop rapide ainsi que le nombre de secondes qu'il doit attendre pour envoyer le formulaire.";
+	$lang['edit_expl_time_lock_value'] = "Le temps minimal en secondes pour le blocage d'envoi, que l'utilisateur doit attendre avant de pouvoir envoyer le formulaire.";
+	$lang['edit_expl_time_lock_maxtime'] = "Le temps maximal en secondes pendant lequel l'utilisateur peut déposer une nouvelle entrée dans le livre d'or. Si ce temps est dépassé avant que l'entrée soit terminée, le blocage d'envoi reprend à zéro.";
 	$lang['edit_expl_user_notification'] = "Permet à l'utilisateur de décider d'être informé par e-Mail lorsque son entrée a été activée.";
 	$lang['edit_expl_user_show_email'] = "Permet à l'utilisateur de décider si son e-Mail est indiqué dans le livre d’hôtes ou non. S’il décoche cette case, personne sauf l’administrateur ne peut lui envoyer d’e-Mail.";
 	$lang['edit_expl_session_timeout'] = "Un utilisateur est automatiquement déconnecté, s’il est inactif pendant cette période. Indication en <b>secondes</b>. La valeur doit être >= <b>60</b>.";
@@ -249,7 +255,7 @@
 	$lang['r_deactivate'] = "Désactiver les entrées:";
 	$lang['r_delete'] = "Supprimer les entrées:";
 	$lang['r_edit'] = "Éditer les entrées:";
-	$lang['r_spam'] = "Manage spam:";
+	$lang['r_spam'] = "Administration Spam:";
 	$lang['old_password'] = "Votre mot de passe actuel:";
 	$lang['new_password_1'] = "Mot de passe:";
 	$lang['new_password_2'] = "Confirmer le mot de passe:";
@@ -259,7 +265,7 @@
 	$lang['edit_user_caption_delete_user'] = "Supprimer cet utilisateur";
 	$lang['edit_user_caption_old_password'] = "Votre mot de passe actuel:";
 	$lang['user_add'] = "Ajouter un utilisateur";
-	$lang['user_edit'] = "Éditer utilisateur";	
+	$lang['user_edit'] = "Éditer utilisateur";
 	$lang['edit_user_caption_send_account_data'] = "Envoyer les données";
 	$lang['send_account_data'] = "Envoyer par e-Mail?";
 
@@ -270,7 +276,7 @@
 	$lang['old_version'] = "Votre version est dépassée.<br>Une mise à jour est recommandée.<br><br><a href='http://www.m-gb.org/index.php?id=download_gb' class='admin' target='_blank' title='Actualiser maintenant'>À la version actuelle</a>";
 	$lang['same_version'] = "Vous avez la version la plus récente.<br>Une mise à jour n’est pas nécessaire.";
 	$lang['newer_version'] = "Votre version est plus récente que la version stable disponible.<br>Une mise à jour n’est pas nécessaire.";
-	$lang['new_version_available'] = "A new version is available: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Upgrade now!'>{LATEST_VERSION}</a>";
+	$lang['new_version_available'] = "Une nouvelle version est disponible: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Actualiser maintenant'>{LATEST_VERSION}</a>";
 
 // lostpassword.php
 	$lang['lostpassword_mail'] = "Votre adresse e-Mail:";
