@@ -1,7 +1,7 @@
 <?php
 	/*
 	MGB 0.6.x - OpenSource PHP and MySql Guestbook
-	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/
+	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -19,17 +19,17 @@
 	*/
 
 	// ================== //
-	// newentry.php - 1.0 //
+	// newentry.php - 1.4 //
 	// ================== //
 	//
 	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
-	
+
 	// show all errors
 	error_reporting(E_ALL & ~E_NOTICE);
-	
+
 	header("Cache-Control: no-cache, must-revalidate"); // HTTP/1.1
 	header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Datum in der Vergangenheit
-	
+
 	// check if MGB has been already installed
 	if (file_exists("includes/config.inc.php"))
 		{
@@ -54,8 +54,43 @@
 	require ("language/".$settings['language_path']."/settings.php");
 	require ("includes/load_templates.inc.php");
 
+	if (isset($settings['time_lock']) AND $settings['time_lock'] == 1)
+		{
+		// start session for anti-spam-time-lock
+		session_name("time_lock");
+		ini_set('url_rewriter.tags', '');
+		session_start();
+		session_regenerate_id();
+
+		// set start time
+		if (isset($_SESSION['start_time']))
+			{
+			if (time() > ($_SESSION['start_time'] + $settings['time_lock_maxtime']))
+				{
+				$_SESSION['start_time'] = time();
+				}
+			}
+		else
+			{
+			$_SESSION['start_time'] = time();
+			}
+		}
+
 	if (isset($_POST['send']) AND $_POST['send'] == $lang['send'])
 		{
+		if (isset($settings['time_lock']) AND $settings['time_lock'] == 1)
+			{
+			// time check for formular load
+			$actual_time = time();
+			$difference = $actual_time - $_SESSION['start_time'];
+
+			if ($difference < $settings['time_lock_value'])
+				{
+				$errorcode = 10;
+				$rest = $settings['time_lock_value'] - $difference;
+				}
+			}
+
 		// delete html, php code and white spaces
 		
 		if(!isset($_POST['user_notification'])) { $_POST['user_notification'] = 0; }
@@ -72,19 +107,151 @@
 		$_POST['user_notification'] = cleanstr($_POST['user_notification']);
 		$_POST['user_show_email'] = cleanstr($_POST['user_show_email']);
 
-		// form was sent
+		// include akismet if it exists
+		if (file_exists("plugins/akismet/akismet.class.php") AND (isset($settings['akismet_api'])) AND ($settings['akismet_api'] != "") AND ($_POST['name'] != "") AND ($_POST['email'] != "") AND ($_POST['message'] != ""))
+			{
+			include ("plugins/akismet/akismet.class.php");
+
+			$akismet_author = bbcode_delete($_POST['name']);
+			$akismet_email = bbcode_delete($_POST['email']);
+			$akismet_website = bbcode_delete($_POST['hp']);
+			$akismet_body = bbcode_delete($_POST['message']);
+
+			// check for spam
+			// Load array with comment data.
+			$comment = array(
+				'author' => $akismet_author,
+				'email' => $akismet_email,
+				'website' => $akismet_website,
+				'body' => $akismet_body,
+				'permalink' => 'http://'.$settings['h_domain'].$settings['gb_path'],
+				'user_ip' => $_SERVER['REMOTE_ADDR'], // Optional, if not in array defaults to $_SERVER['REMOTE_ADDR'].
+				'user_agent' => $_SERVER['HTTP_USER_AGENT'], // Optional, if not in array defaults to $_SERVER['HTTP_USER_AGENT'].
+				);
+
+			// Instantiate an instance of the class.
+			$akismet = new Akismet('http://'.$settings['h_domain'].$settings['gb_path'], $settings['akismet_api'], $comment);
+
+			// Test for errors.
+			if($akismet->errorsExist())
+				{ // Returns true if any errors exist.
+				if($akismet->isError('AKISMET_INVALID_KEY'))
+					{
+					echo "AKISMET API KEY INVALID";
+					}
+				elseif($akismet->isError('AKISMET_RESPONSE_FAILED'))
+					{
+					echo "AKISMET RESPONSE FAILED";
+					}
+				elseif($akismet->isError('AKISMET_SERVER_NOT_FOUND'))
+					{
+					echo "AKISMET_SERVER_NOT_FOUND";
+					}
+				}
+			else
+				{
+				// No errors, check for spam.
+				if ($akismet->isSpam())
+					{
+					// if is set in the admin panel, mark the entry as spam
+					if (isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
+						{
+						$mark_as_spam = 1;
+						$noemail = 1;
+						}
+					else
+						{
+						$mark_as_spam = 0;
+						$noemail = 0;
+						}
+					}
+				}
+			}
+
+		// THE CAKE IS A LIE!
+
+		// search for content to identify spam
+		$string = bbcode_delete($_POST['message']);
+		$searchstring = "Hi there, very nice homepage :-)";
+		$pos = strpos($string, $searchstring);
+
+		if ($pos !== false)
+			{
+			// if is set in the admin panel, mark the entry as spam
+			if (isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
+				{
+				$mark_as_spam = 1;
+				$noemail = 1;
+				}
+			else
+				{
+				$mark_as_spam = 0;
+				$noemail = 0;
+				}
+			}
+	
+		// following IP adresses will be blocked. Add desired IPs to the array.
+		// NOTE: the last entry has to be without a comma at the end like here:
+		//
+		// $string = array(
+		// 'xxx.xxx.xxx.xxx',
+		// 'xxx.xxx.xxx.xxx',
+		// 'xxx.xxx.xxx.xxx'	 <-- see? no comma :)
+		// );
+
+	  // Array for blocked IPs
+	  $blocked_ips = array(
+			'xxx.xxx.xxx.xxx',
+			'xxx.xxx.xxx.xxx',
+			'xxx.xxx.xxx.xxx'
+			);
+
+		 foreach ($blocked_ips as $ip)
+			{
+			if ($_SERVER["REMOTE_ADDR"] == $ip)
+				{
+				// if is set in the admin panel, mark the entry as spam
+				if (isset($settings['akismet_mark_as_spam']) AND ($settings['akismet_mark_as_spam'] == 1))
+					{
+					$mark_as_spam = 1;
+					$noemail = 1;
+					}
+				else
+					{
+					$mark_as_spam = 0;
+					$noemail = 0;
+					}
+				}
+			}
+
+		// form was sent and is ok!
 		// check if captcha is correct
 		if ($settings['captcha'] == 1)
 			{
-			$sql = "SELECT `code` FROM ".$db['prefix']."captcha LIMIT 1";
-			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 80: ".mysql_error());
-			mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 81: ".mysql_error());
-			$result = mysql_query($sql, $link) or die ("(newentry.php) Error, line 82: ".mysql_error());
+			if ($settings['captcha_method'] == 0)
+				{
+				$sql = "SELECT `code` FROM ".$db['prefix']."captcha LIMIT 1";
+				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 80: ".mysql_error());
+				mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 81: ".mysql_error());
+				$result = mysql_query($sql, $link) or die ("(newentry.php) Error, line 82: ".mysql_error());
 
-			$saved_code = @mysql_fetch_array($result);
-			$captcha_code = $saved_code['code'];
+				$saved_code = @mysql_fetch_array($result);
+				$captcha_code = $saved_code['code'];
 
-			if ($captcha_code != $_POST['captcha']) { $errorcode = 7; }
+				if ($captcha_code != $_POST['captcha']) { $errorcode = 7; }
+				}
+			elseif ($settings['captcha_method'] == 1)
+				{
+				$sql = "SELECT `sum` FROM ".$db['prefix']."captcha_math LIMIT 1";
+				$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 131: ".mysql_error());
+				mysql_select_db($db['dbname'], $link) or die ("(newentry.php) Error, line 132: ".mysql_error());
+				$result = mysql_query($sql, $link) or die ("(newentry.php) Error, line 133: ".mysql_error());
+
+				$saved_code = @mysql_fetch_array($result);
+				$captcha_code = $saved_code['sum'];
+
+				if ($captcha_code != $_POST['captcha']) { $errorcode = 7; }
+				}
 			}
 
 		// if you want the email field to be not necessary, just outcomment next line with "//"
@@ -126,7 +293,7 @@
 			if ($_POST['hp'] == "http://"){ $_POST['hp'] = ""; }
 
 			// check if "moderated gb" and "user email notification" is on
-			if ($settings['moderated'] == 1) { $checked = 0; } else { $checked = 1; }
+			if (($settings['moderated'] == 1) OR ($mark_as_spam == 1)) { $checked = 0; } else { $checked = 1; }
 			if ($settings['user_notification'] == 0 OR empty($_POST['email'])) { $_POST['user_notification'] = 0; }
 			if ($settings['user_show_email'] == 0 OR empty($_POST['email'])) { $_POST['user_show_email'] = 0; }
 
@@ -150,7 +317,8 @@
 								timestamp,
 								user_notification,
 								user_show_email,
-								checked
+								checked,
+								isspam
 							   ) values (
 								'".$_POST['name']."',
 								'".$_POST['city']."',
@@ -164,7 +332,8 @@
 								'".$time."',
 								'".$_POST['user_notification']."',
 								'".$_POST['user_show_email']."',
-								'".$checked."'
+								'".$checked."',
+								'".$mark_as_spam."'
 							   )";
 			
 			$link = @mysql_connect($db['hostname'], $db['username'], $db['password']) or die ("(newentry.php) Error, line 170: ".mysql_error());
@@ -181,7 +350,7 @@
 			$_POST['message'] = xhtmlbr2nl($_POST['message']);
 			
 			// send an email to admin
-			if($settings['sendmail_admin'] == 1)
+			if(($settings['sendmail_admin'] == 1) AND ($noemail == 0))
 				{
 				$date = date("d"."/"."m"."/"."Y");
 				$time = date("H".":"."i");
@@ -205,7 +374,7 @@
 				}
 			
 			// send an email to user
-			if($settings['sendmail_user'] == 1 AND isset($_POST['email']))
+			if($settings['sendmail_user'] == 1 AND isset($_POST['email']) AND ($noemail == 0))
 				{
 				$date = date("d"."/"."m"."/"."Y");
 				$time = date("H".":"."i");
@@ -218,7 +387,7 @@
 				$mail_header = "content-type: text/plain; charset=".$charset."\n";
 				$mail_header .= "from: ".$settings['admin_gbemail']; 
 				
-				if ( mail($_POST['email'], $lang['sendmail_user_title'], $settings['sendmail_user_text'], $mail_header) )
+				if (mail($_POST['email'], $lang['sendmail_user_title'], $settings['sendmail_user_text'], $mail_header) )
 					{
 					$sendemail_successfull = 1;
 					}
@@ -230,6 +399,11 @@
 
 			$entry_successfull = 1;
 
+			if (isset($settings['time_lock']) AND $settings['time_lock'] == 1)
+				{
+				session_destroy();
+				}
+
 			// refresh site
 			$refresh = "<meta http-equiv=\"refresh\" content=\"5; URL=index.php\">";
 			}
@@ -241,14 +415,22 @@
 			if ($errorcode == 4) { $errormessage = $_POST['email']."&nbsp;".$lang['errormessage4']; }
 			if ($errorcode == 5) { $errormessage = $_POST['icq']."&nbsp;".$lang['errormessage5']; }
 			if ($errorcode == 7) { $errormessage = $lang['errormessage7']; }
+			if ($errorcode == 10) { $errormessage = $lang['errormessage10']; }
 
 			// do not refresh site
 			$refresh = "";
 
-			// generate new captchacode if activated
-			if ($settings['captcha'] == 1)
+			// generate captchacode if activated
+			if(($settings['captcha'] == 1) AND ($captcha_generated != 1))
 				{
-				generate_captcha();
+				generate_captcha($settings['captcha_method']);
+				$captcha_img = "<img src=\"includes/captcha.inc.php\" class=\"captcha\" title=\"".$lang['security_code']."\" alt=\"".$lang['security_code']."\">";
+				$captcha_img = preg_replace("/\{CAPTCHA_IMG\}/", $captcha, $content_captcha);
+				$captcha_generated = 1;
+				}
+			elseif ($settings['captcha'] == 0)
+				{
+				$captcha_img = "";
 				}
 			}
 		// don't show preview here
@@ -314,13 +496,20 @@
 			}
 
 		if(!isset($lastIP)) { $lastIP = NULL; }
-		
+
 		if ($lastIP == $_SERVER["REMOTE_ADDR"]) { $errorcode = 6;  $errormessage = $lang['errormessage6']; }
-		
+
 		// generate captchacode if activated
-		if ($settings['captcha'] == 1)
+		if(($settings['captcha'] == 1) AND ($captcha_generated != 1))
 			{
-			generate_captcha();
+			generate_captcha($settings['captcha_method']);
+			$captcha_img = "<img src=\"includes/captcha.inc.php\" class=\"captcha\" title=\"".$lang['security_code']."\" alt=\"".$lang['security_code']."\">";
+			$captcha_img = preg_replace("/\{CAPTCHA_IMG\}/", $captcha, $content_captcha);
+			$captcha_generated = 1;
+			}
+		elseif ($settings['captcha'] == 0)
+			{
+			$captcha_img = "";
 			}
 		}
 
@@ -405,7 +594,7 @@
 		$content_newentry_bbcodes = preg_replace("/\{LANG_BBCODE_EXTRABIG\}/", $lang['bbcode_extrabig'], $content_newentry_bbcodes);		
 		$content_newentry_bbcodes = preg_replace("/\{LANG_BBCODE_TEXTCOLOR\}/", $lang['bbcode_textcolor'], $content_newentry_bbcodes);
 		$bbcodes = $content_newentry_bbcodes;
-		 }
+		}
 	else
 		{
 		$bbcodes = NULL;
@@ -434,15 +623,16 @@
 		}
 
 	// fill template with captcha
-	if ($settings['captcha'] == 1)
+	if(($settings['captcha'] == 1) AND ($captcha_generated != 1))
 		{
-		generate_captcha();
+		generate_captcha($settings['captcha_method']);
 		$captcha_img = "<img src=\"includes/captcha.inc.php\" class=\"captcha\" title=\"".$lang['security_code']."\" alt=\"".$lang['security_code']."\">";
-		$captcha_img = preg_replace("/\{CAPTCHA_IMG\}/", $captcha_img, $content_captcha);
+		$captcha_img = preg_replace("/\{CAPTCHA_IMG\}/", $captcha, $content_captcha);
+		$captcha_generated = 1;
 		}
-	else
+	elseif ($settings['captcha'] == 0)
 		{
-		$captcha_img = NULL;
+		$captcha_img = "";
 		}
 
 	// footer
@@ -463,16 +653,18 @@
 		$page_newentry_body = preg_replace("/\{TEMPLATE_USER_NOTIFICATION\}/", $user_notification, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_USER_SHOW_EMAIL\}/", $user_show_email, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_CAPTCHA\}/", $captcha_img, $page_newentry_body);
-		$page_newentry_body = preg_replace("/\{COPYRIGHT\}/", $content_copyright, $page_newentry_body);
-		$page_newentry_body = preg_replace("/\{FOOTER\}/", $page_footer, $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{TEMPLATE_COPYRIGHT\}/", $content_copyright, $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{TEMPLATE_FOOTER\}/", $page_footer, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{MGB_VERSION\}/", $settings['version'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{COPYRIGHT_DATE\}/", date("Y"), $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{ICONSET_PATH\}/", $settings['iconset_path'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_PATH\}/", "templates/".$settings['template_path'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_STYLE_PATH\}/", $settings['template_style_path'], $page_newentry_body);
 
 		// fill template with language strings
 		if(!isset($errormessage)) { $errormessage = NULL; }
 		$page_newentry_body = preg_replace("/\{ERRORMESSAGE\}/", $errormessage, $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{TIME_LOCK_REST\}/", $rest, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TITLE\}/", $settings['title'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{LANG_NEW_ENTRY_NAME\}/", $lang['name'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{LANG_NEW_ENTRY_CITY\}/", $lang['city'], $page_newentry_body);
@@ -505,7 +697,7 @@
 			$_POST['hp'] = "http://";
 			$_POST['message'] = "";
 			}
-			
+
 		$page_newentry_body = preg_replace("/\{POST_NAME\}/", $_POST['name'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{POST_CITY\}/", $_POST['city'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{POST_EMAIL\}/", $_POST['email'], $page_newentry_body);
@@ -530,13 +722,14 @@
 		$page_newentry_body = preg_replace("/\{LANG_FORWARDING\}/", $lang['forwarding'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{LANG_BACK\}/", $lang['back'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{LANG_BACK_TO_MAINPAGE\}/", $lang['back_to_mainpage'], $page_newentry_body);
-		$page_newentry_body = preg_replace("/\{COPYRIGHT\}/", $content_copyright, $page_newentry_body);
-		$page_newentry_body = preg_replace("/\{FOOTER\}/", $page_footer, $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{TEMPLATE_COPYRIGHT\}/", $content_copyright, $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{TEMPLATE_FOOTER\}/", $page_footer, $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{MGB_VERSION\}/", $settings['version'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{COPYRIGHT_DATE\}/", date("Y"), $page_newentry_body);
+		$page_newentry_body = preg_replace("/\{ICONSET_PATH\}/", $settings['iconset_path'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_PATH\}/", "templates/".$settings['template_path'], $page_newentry_body);
 		$page_newentry_body = preg_replace("/\{TEMPLATE_STYLE_PATH\}/", $settings['template_style_path'], $page_newentry_body);
 		}
 
 	echo $page_newentry_body;
-?>
\ No newline at end of file
+?>
